using System.ServiceModel;

namespace RGDWCSServices
{
    [ServiceContract]
    public interface IRGDWCSService
    {
        [OperationContract]
        string getWhEquipStatus(string xml);
        [OperationContract]
        string packTask(string xml);
        [OperationContract]
        string startArrangeTask(string xml);
        [OperationContract]
        string startInTask(string xml);
        [OperationContract]
        string startInventoryTask(string xml);
        [OperationContract]
        string startBoxInvTask(string xml);
        [OperationContract]
        string startOutTask(string xml);
        [OperationContract]
        string stopTask(string xml);


        [OperationContract]
        string RFIDReadyToRead(string station_code);
        [OperationContract]
        string RFIDRequestWithReturn(string RFIDRequest);

        [OperationContract]
        int ReadyToHandleVision(string station_code);
        [OperationContract]
        string VISIONRequestWithReturn(string VISIONRequest);

        [OperationContract]
        int Update_IO_Vision(string device_code, int read_flag);
    }
}